// JS target: IE 11+

// polyfills:
if (!Element.prototype.matches) {
  Element.prototype.matches =
    Element.prototype.msMatchesSelector ||
    Element.prototype.webkitMatchesSelector;
}
if (!Element.prototype.closest) {
  Element.prototype.closest = function(s) {
    var el = this;
    if (!document.documentElement.contains(el)) { return null; }
    do {
      if (el.matches(s)) { return el; }
      el = el.parentElement || el.parentNode;
    } while (el !== null && el.nodeType === 1);
    return null;
  };
}


function plainArray(arrayLike) {
  return Array.prototype.slice.apply(arrayLike);
}

function each(arr, cb) {
  Array.prototype.forEach.call(arr, cb);
}

function find(arr, fn) {
  for (var i = 0, len = arr.length; i < len; i++) {
    if (fn(arr[i], i)) { return arr[i]; }
  }
}

function isHidden(el) {
  return el.offsetParent === null || /* ie 9-10 */ el.parentNode === document.body;
}

function pick(obj, keys) {
  var out = {};
  keys.forEach(function (key) {
    if (key in obj) {
      out[key] = obj[key];
    }
  });
  return out;
}

function assign(to, varArgs) {
  var arguments$1 = arguments;

  for (var index = 1; index < arguments.length; index++) {
    var nextSource = arguments$1[index];
    if (nextSource != null) {
      for (var nextKey in nextSource) {
        if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
          to[nextKey] = nextSource[nextKey];
        }
      }
    }
  }
  return to;
}

function toggleClass(el, className, value) {
  if (value) {
    el.classList.add(className);
  } else {
    el.classList.remove(className);
  }
}

// measure the height of each element within the views and place them in approximately equal columns
function columnize(el, columns) {
  var children = Array.prototype.slice.apply(el.children);
  var colHeight = children.reduce(function (a, n) { return a + n.offsetHeight; }, 0) / columns;

  var columnsData = [];
  for (var i = 0; i < columns; i++) {
    columnsData.push({ height: 0, elements: [] });
  }

  var column = 0;
  children.forEach(function (child) {
    var colData = columnsData[column];
    colData.elements.push(child);
    colData.height += child.offsetHeight;
    if (colData.height >= colHeight) {
      column++;
    }
  });

  var rowEl = document.createElement('row');
  rowEl.className = 'row';
  columnsData.forEach(function (colData) {
    var colEl = document.createElement('div');
    colEl.className = 'col-lg col-lg--1';
    colData.elements.forEach(function (child) { return colEl.appendChild(child); });
    rowEl.appendChild(colEl);
  });
  el.appendChild(rowEl);
}

var View = function View() {
  this.el = null;
};

View.attach = function attach (el) {
  var instance = new this();
  instance.attach(el);
};

	View.prototype.bindEvents = function bindEvents (ev) {
		var this$1 = this;

		var self = this;
		var loop = function ( key ) {
			var components = key.split(' ');
			var event = components[0], filter = components.slice(1).join(' ');
			var callback = ev[key];
			var el = this$1.el;
			if (event && callback) {
				if (filter) {
					el.addEventListener(event, function (e) {
						var filteredEl = e.target.closest(filter);
						if (filteredEl) {
							callback.call(self, filteredEl, e);
						}
					});
				} else {
					el.addEventListener(event, function (e) {
						callback.call(self, e.target, e);
					});
				}
			}
		};

		for (var key in ev) loop( key );
	};

var TagSummary = (function (View) {
  function TagSummary() {
    View.call(this);
    this.tagsEl = null;
    this.showAllEl = null;
    this.collapsed = false;
  }

  if ( View ) TagSummary.__proto__ = View;
  TagSummary.prototype = Object.create( View && View.prototype );
  TagSummary.prototype.constructor = TagSummary;

  TagSummary.prototype.attach = function attach (el) {
    this.el = el;
    this.tagsEl = el.querySelector('.tag-summary__tags');
    this.showAllEl = el.querySelector('.tag-summary__show-all');
    this.checkCollapsable();
  };

  TagSummary.prototype.checkCollapsable = function checkCollapsable () {
    var this$1 = this;

    this.setCollapsed(false);
    var collapsable = this.tagsEl.offsetHeight > 50;
    if (collapsable) {
      this.el.querySelector('.tag-summary__show-all').classList.remove('d-none');
      this.showAllEl.addEventListener('click', function () { return this$1.setCollapsed(!this$1.collapsed); });
      this.setCollapsed(true);
    }
  };

  TagSummary.prototype.setCollapsed = function setCollapsed (collapsed) {
    this.collapsed = collapsed;
    toggleClass(this.el, 'tag-summary--collapsed', collapsed);
    toggleClass(this.showAllEl.querySelector('.caret'), 'caret--up', !collapsed);
  };

  return TagSummary;
}(View));

var Dropdown = (function (View) {
  function Dropdown() {
    View.call(this);
    this.visible = false;
    this.handleToggleClick = this.handleToggleClick.bind(this);
    this.cancel = this.cancel.bind(this);
  }

  if ( View ) Dropdown.__proto__ = View;
  Dropdown.prototype = Object.create( View && View.prototype );
  Dropdown.prototype.constructor = Dropdown;

  Dropdown.prototype.attach = function attach (el) {
    this.el = el;
    var toggle = this.el.querySelector('.dropdown__toggle')
    if (toggle) { toggle.addEventListener('click', this.handleToggleClick); }
  };

  Dropdown.prototype.handleToggleClick = function handleToggleClick (e) {
    e.preventDefault();
    this.setVisible(!this.visible);
  };

  Dropdown.prototype.cancel = function cancel () {
    this.setVisible(false);
  };

  Dropdown.prototype.setVisible = function setVisible (visible) {
    var this$1 = this;

    if (this.visible == visible) { return; }
    this.visible = visible;
    setTimeout(function () {
      if (visible) {
        document.body.addEventListener('click', this$1.cancel);
      } else {
        document.body.removeEventListener('click', this$1.cancel);
      }
    });
    toggleClass(this.el, 'dropdown--open', visible);
  };

  return Dropdown;
}(View));

var Gallery = (function (View) {
  function Gallery() {
    View.call(this);
    this.r18 = false;
    this.toggle = null;
    this.handleSwitchClick = this.handleSwitchClick.bind(this);
  }

  if ( View ) Gallery.__proto__ = View;
  Gallery.prototype = Object.create( View && View.prototype );
  Gallery.prototype.constructor = Gallery;

  Gallery.prototype.attach = function attach (el) {
    this.el = el;
    this.toggle = this.el.querySelector('.gallery-r18-toggle');
    if (this.toggle) { this.toggle.addEventListener('click', this.handleSwitchClick); }
    this.bindEvents({
      'click .gallery__image-link': this.imageClick
    });
  };

  Gallery.prototype.handleSwitchClick = function handleSwitchClick () {
    this.setR18(!this.r18);
  };

  Gallery.prototype.setR18 = function setR18 (r18) {
    this.r18 = r18;
    toggleClass(this.el, 'gallery--show-r18', r18);
    toggleClass(this.toggle, 'switch--on', r18);
  };

  Gallery.prototype.imageClick = function imageClick (el, e) {
    e.preventDefault();
    this.openLightbox({ currentEl: el });
  };

  Gallery.prototype.openLightbox = function openLightbox (ref) {
    var this$1 = this;
    var currentEl = ref.currentEl;

    var images = [];
    var currentIndex = 0;
    each(this.el.querySelectorAll('.gallery__image-link'), function (el) {
      if (el.classList.contains('gallery__image--r18') && !this$1.r18) { return; }
      var imageData = this$1.extractImageData(el);
      images.push(imageData);
      if (el == currentEl) { currentIndex = images.length - 1; }
    });

    if (images.length == 0) { return; }

    var lightbox = new Lightbox({ images: images, index: currentIndex });
    lightbox.show();
  };

  Gallery.prototype.extractImageData = function extractImageData (el) {
    var size = el.dataset.fullImageSize.split('x').map(function (x) { return Number(x); });
    return {
      src: el.href,
      thumbSrc: el.querySelector('.gallery__image').src,
      width: size[0],
      height: size[1]
    };
  };

  return Gallery;
}(View));

var Lightbox = (function (View) {
  function Lightbox(ref) {
    var images = ref.images;
    var index = ref.index;

    View.call(this);
    this.images = images.map(function (x, i) { return (assign({}, x, {index: i})); });
    this.index = index || 0;
    this.currentPreload = false;
    this.preloadQueue = [];
    this.handleKeyDown = this.handleKeyDown.bind(this);
    this.handleWinResize = this.handleWinResize.bind(this);
    this.handleBackgroundClick = this.handleBackgroundClick.bind(this);
  }

  if ( View ) Lightbox.__proto__ = View;
  Lightbox.prototype = Object.create( View && View.prototype );
  Lightbox.prototype.constructor = Lightbox;

  Lightbox.prototype.show = function show () {
    var this$1 = this;

    this.el = document.createElement('div');
    this.el.classList.add('lightbox');
    this.el.innerHTML = '<a href="javascript:;" class="lightbox__close"></a>' +
      '<a class="lightbox__image lightbox__image-left"><img class="lightbox__img"></a>' +
      '<a class="lightbox__image lightbox__image-current"><img class="lightbox__img"></a>' +
      '<a class="lightbox__image lightbox__image-right"><img class="lightbox__img"></a>';

    document.body.appendChild(this.el);
    document.body.classList.add('lightbox-open');

    document.addEventListener('keydown', this.handleKeyDown);
    window.addEventListener('resize', this.handleWinResize);

    this.el.addEventListener('click', this.handleBackgroundClick);
    this.el.querySelector('.lightbox__close').addEventListener('click', function () { return this$1.hide(); });

    this.bindEvents({
      'click .lightbox__image-left': function (el, e) { return this$1.handleImageClick(e, -1); },
      'click .lightbox__image-current': function (el, e) { return this$1.handleImageClick(e, 1); },
      'click .lightbox__image-right': function (el, e) { return this$1.handleImageClick(e, 1); },
    });

    this.updateImages();
  };

  Lightbox.prototype.hide = function hide () {
    document.body.removeChild(this.el);
    document.body.classList.remove('lightbox-open');
    document.removeEventListener('keydown', this.handleKeyDown);
    window.removeEventListener('resize', this.handleWinResize);
  };

  Lightbox.prototype.handleKeyDown = function handleKeyDown (e) {
    if (e.keyCode == 37) { this.move(-1); }
    if (e.keyCode == 39) { this.move(1); }
    if (e.keyCode == 27) { this.hide(); }
  };

  Lightbox.prototype.handleWinResize = function handleWinResize () {
    this.updateImages({ repositionOnly: true });
  };

  Lightbox.prototype.handleBackgroundClick = function handleBackgroundClick (e) {
    if (e.target != this.el) { return; }
    this.hide();
  };

  Lightbox.prototype.handleImageClick = function handleImageClick (e, direction) {
    e.preventDefault();
    this.move(direction);
  };

  Lightbox.prototype.move = function move (amount) {
    var newIndex = Math.max(Math.min(this.index + amount, this.images.length - 1), 0);
    if (newIndex == this.index) { return; }
    this.index = newIndex;
    this.updateImages();
  };

  Lightbox.prototype.updateImages = function updateImages (opts) {
    if ( opts === void 0 ) opts = { repositionOnly: false };

    var left = this.prepareImage(this.index - 1);
    var current = this.prepareImage(this.index);
    var right = this.prepareImage(this.index + 1);
    this.updateImage(left, this.el.querySelector('.lightbox__image-left'), opts);
    this.updateImage(current, this.el.querySelector('.lightbox__image-current'), opts);
    this.updateImage(right, this.el.querySelector('.lightbox__image-right'), opts);
    if (!opts.repositionOnly) {
      this.updatePreload(current, [right, left].filter(function (x) { return x != null; }));
    }
  };

  Lightbox.prototype.updateImage = function updateImage (data, el, opts) {
    var imgEl = el.querySelector('.lightbox__img');
    el.dataset.index = data ? data.index : -1;
    el.style.height = data ? data.height + 'px' : '';
    el.href = data ? data.src : '';
    imgEl.style.display = data ? 'block' : 'none';
    imgEl.style.width = data ? data.width + 'px' : '';
    imgEl.style.height = data ? data.height + 'px' : '';
    if (!opts.repositionOnly) {
      imgEl.src = data ? data.thumbSrc : '';
    }
  };

  Lightbox.prototype.prepareImage = function prepareImage (index) {
    var def = this.images[index];
    if (!def) { return null; }

    var availableSpace = {
      width: Math.floor(document.documentElement.clientWidth * 0.84),
      height: document.documentElement.clientHeight - 80
    };

    var finalSize = this.fit(def, availableSpace);

    return assign({}, def, finalSize);
  };

  Lightbox.prototype.fit = function fit (size, within) {
    var widthScale = within.width / size.width;
    var heightScale = within.height / size.height;
    var scale = widthScale < heightScale ? widthScale : heightScale;
    if (scale > 1) { scale = 1; }
    return { width: Math.round(size.width * scale), height: Math.round(size.height * scale) };
  };

  Lightbox.prototype.updatePreload = function updatePreload (active, next) {
    this.preloadQueue = next;
    this.startPreload(active);
  };

  Lightbox.prototype.startPreload = function startPreload (active) {
    var this$1 = this;

    if (this.currentPreload) {
      // already loading the same image, we can skip this
      if (this.currentPreload.def.index == active.index) { return; }

      // cancel previous preload
      this.currentPreload.img.src = '';
    }

    var img = new Image();
    var preload = { def: active, img: img };
    img.onload = function () {
      this$1.preloadFinished(preload);
    };

    this.currentPreload = preload;

    img.src = active.src;

    if (img.complete) {
      img.onload();
      img.onload
    }
  };

  Lightbox.prototype.preloadFinished = function preloadFinished (preload) {
    var imgEl = find(
      this.el.querySelectorAll('.lightbox__img'),
      function (x) { return x.parentNode.dataset.index == preload.def.index; }
    );

    if (imgEl) {
      imgEl.src = preload.def.src;
    }

    if (this.currentPreload != preload) {
      // this isn't actually the active preload, so it isn't our job to fire off the next one
      // (this state shouldn't happen, but could if the browser calls onload after we cancel a preload)
      return;
    }

    this.currentPreload = null;

    if (this.preloadQueue.length > 0) {
      this.startPreload(this.preloadQueue.shift());
    }
  };

  return Lightbox;
}(View));

document.addEventListener('DOMContentLoaded', function () {
  each(document.querySelectorAll('.js-columnize'), function (el) {
    columnize(el, Number(el.dataset.columns || 2))
  });

  each(document.querySelectorAll('.tag-summary'), function (el) { return TagSummary.attach(el); });
  each(document.querySelectorAll('.dropdown'), function (el) { return Dropdown.attach(el); });
  each(document.querySelectorAll('.gallery'), function (el) { return Gallery.attach(el); });

  each(document.querySelectorAll('.navbar__toggler'), function (el) {
    el.addEventListener('click', function () {
      el.closest('.navbar').classList.toggle('navbar--expanded');
    });
  })
});

//# sourceMappingURL=vndb.js.map